@@ -22,11 +22,12 @@ impl Topic {
         subscription_name: &str,
         filter: &str,
     ) -> Result<Subscription> {
+        let resource_name = format!(
+            "projects/{}/subscriptions/{}",
+            &self.client.project_id, subscription_name
+        );
         let subs = api::Subscription {
-            name: format!(
-                "projects/{}/subscriptions/{}",
-                &self.client.project_id, subscription_name
-            ),
+            name: resource_name.clone(),
             ack_deadline_seconds: 10,
             dead_letter_policy: None,
             detached: false,
@@ -42,7 +43,7 @@ impl Topic {
         };
         let req = self.client.insert_authz_token(subs).await?;
         self.client.subscriber.create_subscription(req).await?;
-        Ok(Subscription::new(self.client.clone(), subscription_name))
+        Ok(Subscription::new(self.client.clone(), &resource_name))
     }
     pub async fn delete_subscription(&mut self, subscription_name: &str) -> Result<()> {
         let delete_sub_req = api::DeleteSubscriptionRequest {
